public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Jiaxin Wu <jiaxin.wu@intel.com>
To: edk2-devel@lists.01.org
Cc: Ye Ting <ting.ye@intel.com>, Fu Siyuan <siyuan.fu@intel.com>,
	Wu Jiaxin <jiaxin.wu@intel.com>
Subject: [Patch 2/2] NetworkPkg: Typo fix and comments correction
Date: Tue, 13 Jun 2017 14:02:42 +0800	[thread overview]
Message-ID: <1497333762-18940-3-git-send-email-jiaxin.wu@intel.com> (raw)
In-Reply-To: <1497333762-18940-1-git-send-email-jiaxin.wu@intel.com>

warter -> water
Maunual -> Manual
TCP and UDP --> TCP4 and TCP6
TCP or UDP --> TCP4 or TCP6

Cc: Ye Ting <ting.ye@intel.com>
Cc: Fu Siyuan <siyuan.fu@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Wu Jiaxin <jiaxin.wu@intel.com>
---
 NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c |  6 +++---
 NetworkPkg/TcpDxe/Socket.h        | 10 +++++-----
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
index 7575b79..7c7acc7 100644
--- a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
+++ b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
@@ -754,11 +754,11 @@ Ip6ConfigSetDadXmits (
 }
 
 /**
   The callback function for Ip6SetAddr. The prototype is defined
   as IP6_DAD_CALLBACK. It is called after Duplicate Address Detection is performed
-  for the manual address set by Ip6ConfigSetMaunualAddress.
+  for the manual address set by Ip6ConfigSetManualAddress.
 
   @param[in]     IsDadPassed   If TRUE, Duplicate Address Detection passed.
   @param[in]     TargetAddress The tentative IPv6 address to be checked.
   @param[in]     Context       Pointer to the IP6 configuration instance data.
 
@@ -894,11 +894,11 @@ Ip6ManualAddrDadCallback (
   @retval EFI_SUCCESS           The specified configuration data for the EFI IPv6
                                 network stack was set.
 
 **/
 EFI_STATUS
-Ip6ConfigSetMaunualAddress (
+Ip6ConfigSetManualAddress (
   IN IP6_CONFIG_INSTANCE  *Instance,
   IN UINTN                DataSize,
   IN VOID                 *Data
   )
 {
@@ -2216,11 +2216,11 @@ Ip6ConfigInitInstance (
   DataItem->DataSize = sizeof (Instance->DadXmits);
   Instance->DadXmits.DupAddrDetectTransmits = IP6_CONFIG_DEFAULT_DAD_XMITS;
   SET_DATA_ATTRIB (DataItem->Attribute, DATA_ATTRIB_SIZE_FIXED);
 
   DataItem           = &Instance->DataItem[Ip6ConfigDataTypeManualAddress];
-  DataItem->SetData  = Ip6ConfigSetMaunualAddress;
+  DataItem->SetData  = Ip6ConfigSetManualAddress;
   DataItem->Status   = EFI_NOT_FOUND;
 
   DataItem           = &Instance->DataItem[Ip6ConfigDataTypeGateway];
   DataItem->SetData  = Ip6ConfigSetGateway;
   DataItem->Status   = EFI_NOT_FOUND;
diff --git a/NetworkPkg/TcpDxe/Socket.h b/NetworkPkg/TcpDxe/Socket.h
index 371e9ab..f7f4a7a 100644
--- a/NetworkPkg/TcpDxe/Socket.h
+++ b/NetworkPkg/TcpDxe/Socket.h
@@ -359,11 +359,11 @@ typedef enum {
 ///
 ///  The buffer structure of rcvd data and send data used by socket.
 ///
 typedef struct _SOCK_BUFFER {
   UINT32        HighWater;  ///< The buffersize upper limit of sock_buffer
-  UINT32        LowWater;   ///< The low warter mark of sock_buffer
+  UINT32        LowWater;   ///< The low water mark of sock_buffer
   NET_BUF_QUEUE *DataQueue; ///< The queue to buffer data
 } SOCK_BUFFER;
 
 /**
   The handler of protocol for request from socket.
@@ -423,12 +423,12 @@ typedef struct _SOCK_INIT_DATA {
   SOCK_TYPE              Type;
   UINT8                  State;
 
   SOCKET                 *Parent;        ///< The parent of this socket
   UINT32                 BackLog;        ///< The connection limit for listening socket
-  UINT32                 SndBufferSize;  ///< The high warter mark of send buffer
-  UINT32                 RcvBufferSize;  ///< The high warter mark of receive buffer
+  UINT32                 SndBufferSize;  ///< The high water mark of send buffer
+  UINT32                 RcvBufferSize;  ///< The high water mark of receive buffer
   UINT8                  IpVersion;
   VOID                   *Protocol;      ///< The pointer to protocol function template
                                          ///< wanted to install on socket
 
   //
@@ -448,11 +448,11 @@ typedef struct _SOCK_INIT_DATA {
 
   EFI_HANDLE             DriverBinding;   ///< The driver binding handle
 } SOCK_INIT_DATA;
 
 ///
 ///  The union type of TCP and UDP protocol.
 ///
 typedef union _NET_PROTOCOL {
   EFI_TCP4_PROTOCOL      Tcp4Protocol;    ///< Tcp4 protocol
   EFI_TCP6_PROTOCOL      Tcp6Protocol;    ///< Tcp6 protocol
 } NET_PROTOCOL;
@@ -500,11 +500,11 @@ struct _TCP_SOCKET {
   // Interface for low level protocol
   //
   SOCK_PROTO_HANDLER        ProtoHandler;     ///< The request handler of protocol
   UINT8                     ProtoReserved[PROTO_RESERVED_LEN];  ///< Data fields reserved for protocol
   UINT8                     IpVersion;
-  NET_PROTOCOL              NetProtocol;                        ///< TCP or UDP protocol socket used
+  NET_PROTOCOL              NetProtocol;                        ///< TCP4 or TCP6 protocol socket used
   //
   // Callbacks after socket is created and before socket is to be destroyed.
   //
@@ -448,11 +448,11 @@ typedef struct _SOCK_INIT_DATA {
 
 ///
-///  The union type of TCP and UDP protocol.
+///  The union type of TCP4 and TCP6 protocol.
 ///
 typedef union _NET_PROTOCOL {
   SOCK_CREATE_CALLBACK      CreateCallback;   ///< Callback after created
   SOCK_DESTROY_CALLBACK     DestroyCallback;  ///< Callback before destroied
-- 
1.9.5.msysgit.1



  parent reply	other threads:[~2017-06-13  6:01 UTC|newest]

Thread overview: 4+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-06-13  6:02 [Patch 0/2] Typo fix and comments correction Jiaxin Wu
2017-06-13  6:02 ` [Patch 1/2] MdeModulePkg/Network: Typo fix Jiaxin Wu
2017-06-13  6:02 ` Jiaxin Wu [this message]
2017-06-13  6:07 ` [Patch 0/2] Typo fix and comments correction Fu, Siyuan

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1497333762-18940-3-git-send-email-jiaxin.wu@intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox